@@ -105,8 +105,8 @@ class NaPoleonDropboxConnector(object):
         if self.dropbox_backup:
             self.upload(fullname=features_names_full_path, folder='', subfolder='', name = features_names_file_names, overwrite=self.overwrite)
 
-    def local_supervision_npy_save_and_upload(self, starting_date = None, data=None, rebal = None, lower_bound=0.02, upper_bound=0.4, local_root_directory='', user='', supervision_npy_file_suffix=''):
-        supervision_file_name = starting_date.strftime('%d_%b_%Y') + '_' + user + '_' + str(rebal) + '_' + str(lower_bound)+ '_' + str(upper_bound) + supervision_npy_file_suffix
+    def local_supervision_npy_save_and_upload(self, starting_date = None, ending_date = None, data=None, rebal = None, lower_bound=0.02, upper_bound=0.4, local_root_directory='', user='', supervision_npy_file_suffix=''):
+        supervision_file_name = starting_date.strftime('%d_%b_%Y') + '_' +ending_date.strftime('%d_%b_%Y') + '_'+ user + '_' + str(rebal) + '_' + str(lower_bound)+ '_' + str(upper_bound) + supervision_npy_file_suffix
         local_root_directory = Path(local_root_directory)
         local_supervision_npy_path = local_root_directory/supervision_file_name
         print('saving local file '+str(local_supervision_npy_path))
