@@ -457,7 +457,7 @@ def perf_strat(underlying, signals=None, log=False, base=100.,
     return perf_returns(series, log=log, base=base)
 
 
-def sharpe(series, period=252):
+def sharpe(series, period=252, from_ret = False):
     r""" Compute the Sharpe ratio [6]_.
 
     Notes
@@ -499,9 +499,11 @@ def sharpe(series, period=252):
     mdd, calmar, drawdown, roll_sharpe
 
     """
-
     series = np.asarray(series, dtype=np.float64).flatten()
-    ret_vect = series[1:] / series[:-1] - 1.
+    if from_ret:
+        ret_vect = series
+    else:
+        ret_vect = series[1:] / series[:-1] - 1.
     return math.sqrt(period)*np.mean(ret_vect)/np.std(ret_vect, dtype=np.float64)
 
 def roll_sharpe(series, period=252, win=0, cap=True):
